@@ -11,8 +11,22 @@ from nonebot.adapters.onebot.v11 import (
 
 import nonebot
 import asyncio
+import re
+import random
+
+from .utils import (
+    MyThesaurus,
+    LeafThesaurus,
+    AnimeThesaurus,
+    get_chat_result,
+    hello__bot,
+    hello__reply,
+    poke__reply,
+    unknow_reply,
+    interrupt_msg,
+    messagePreprocess
+    )
 
-from .utils import *
 from .config import Config
 
 # 加载全局配置
@@ -42,27 +56,28 @@ else:
 # 优先级99，条件：艾特bot就触发
 
 if reply_type > -1:
-    ai = on_message(rule = to_me(), permission = permission, priority=99, block=False)
+    talk = on_message(rule = to_me(), permission = permission, priority=99, block=False)
 
-    @ai.handle()
+    @talk.handle()
     async def _(event: MessageEvent):
         # 获取消息文本
         msg = str(event.get_message())
         # 去掉带中括号的内容(去除cq码)
         msg = re.sub(r"\[.*?\]", "", msg)
+
         # 如果是光艾特bot(没消息返回)，就回复以下内容
         if (not msg) or msg.isspace():
-            if reply_type > 1:
-                await ai.finish(Message(random.choice(hello__reply)))
-            else:
-                await ai.finish()
+            await talk.finish(Message(random.choice(hello__reply)))
+
         # 如果是打招呼的话，就回复以下内容
         if  msg in hello__bot:
-            await ai.finish(Message(random.choice(hello__reply)))
+            await talk.finish(Message(random.choice(hello__reply)))
+
         # 如果是已配置的忽略项，直接结束事件
         for i in range(len(ignore)):
             if msg.startswith(ignore[i]):
-                await ai.finish()
+                await talk.finish()
+
         # 获取用户nickname
         if isinstance(event, GroupMessageEvent):
             nickname = event.sender.card or event.sender.nickname
@@ -71,27 +86,27 @@ if reply_type > -1:
 
         if len(nickname) > 10:
             nickname = nickname[:2] + random.choice(["酱","亲","ちゃん","同志","老师"])
-        # 从个人字典里获取结果（优先）
-        result = await get_chat_result_my(msg,  nickname)
-        if result != None:
-            await ai.finish(Message(result))
-        # 从LeafThesaurus里获取结果
-        result = await get_chat_result_leaf(msg,  nickname)
-        if result != None:
-            await ai.finish(Message(result))
-        # 从AnimeThesaurus里获取结果
-        result = await get_chat_result(msg,  nickname)
-        if result != None:
-            await ai.finish(Message(result))
-        # 随机回复cant__reply的内容
-        if reply_type > 0:
-            await ai.finish(Message(random.choice(cant__reply)))
+
+        # 从个人字典里获取结果
+        if result := get_chat_result(MyThesaurus, msg):
+            await talk.finish(Message(result))
+
+        # 从 LeafThesaurus 里获取结果
+        if result := get_chat_result(LeafThesaurus,msg):
+            await talk.finish(Message(result.replace("name", nickname)))
+
+        # 从 AnimeThesaurus 里获取结果
+        if result := get_chat_result(AnimeThesaurus,msg):
+            await talk.finish(Message(result.replace("你", nickname)))
+
+        # 不明白的内容
+        if reply_type == 1:
+            await talk.finish(Message(random.choice(unknow_reply)))
 
 # 优先级10，不会向下阻断，条件：戳一戳bot触发
 
 if poke_rand > -1:
     poke_ = on_notice(rule = to_me(), priority=10, block=False)
-
     @poke_.handle()
     async def _poke_event(event: PokeNotifyEvent):
         if event.is_tome:
